@@ -2,7 +2,7 @@ package CPAN::HandleConfig;
 use strict;
 use vars qw(%can %keys $VERSION);
 
-$VERSION = sprintf "%.6f", substr(q$Rev: 1379 $,4)/1000000 + 5.4;
+$VERSION = sprintf "%.6f", substr(q$Rev: 1399 $,4)/1000000 + 5.4;
 
 %can = (
         commit   => "Commit changes to disk",
@@ -16,6 +16,7 @@ $VERSION = sprintf "%.6f", substr(q$Rev: 1379 $,4)/1000000 + 5.4;
 # A2: svn diff -r 985:986 # where andk added yaml_module
 %keys = map { $_ => undef }
     (
+     "applypatch",
      "build_cache",
      "build_dir",
      "build_dir_reuse",
@@ -124,13 +125,21 @@ sub edit {
         unless (exists $keys{$o}) {
             $CPAN::Frontend->mywarn("Warning: unknown configuration variable '$o'\n");
         }
+        my $changed;
+
+
         # one day I used randomize_urllist for a boolean, so we must
         # list them explicitly --ak
-	if ($o =~ /^(wait_list|urllist|dontload_list)$/) {
+	if (0) {
+        } elsif ($o =~ /^(wait_list|urllist|dontload_list)$/) {
+
+            #
+            # ARRAYS
+            #
+
 	    $func = shift @args;
 	    $func ||= "";
             CPAN->debug("func[$func]args[@args]") if $CPAN::DEBUG;
-            my $changed;
 	    # Let's avoid eval, it's easier to comprehend without.
 	    if ($func eq "push") {
 		push @{$CPAN::Config->{$o}}, @args;
@@ -156,7 +165,6 @@ sub edit {
                 $self->prettyprint($o);
 	    }
             if ($changed) {
-                $CPAN::CONFIG_DIRTY = 1;
                 if ($o eq "urllist") {
                     # reset the cached values
                     undef $CPAN::FTP::Thesite;
@@ -166,24 +174,38 @@ sub edit {
                     $CPAN::META->{dontload_hash} = {};
                 }
             }
-            return $changed;
         } elsif ($o =~ /_hash$/) {
+
+            #
+            # HASHES
+            #
+
             if (@args==1 && $args[0] eq ""){
                 @args = ();
             } elsif (@args % 2) {
                 push @args, "";
             }
             $CPAN::Config->{$o} = { @args };
-            $CPAN::CONFIG_DIRTY = 1;
+            $changed = 1;
         } else {
+
+            #
+            # SCALARS
+            #
+
             if (defined $args[0]){
                 $CPAN::CONFIG_DIRTY = 1;
                 $CPAN::Config->{$o} = $args[0];
+                $changed = 1;
             }
 	    $self->prettyprint($o)
                 if exists $keys{$o} or defined $CPAN::Config->{$o};
-            return 1;
 	}
+        if ($changed) {
+            $CPAN::CONFIG_DIRTY = 1;
+            $CPAN::Frontend->myprint("Please use 'o conf commit' to ".
+                                     "make the config permanent!\n\n");
+        }
     }
 }
 
@@ -653,7 +675,7 @@ sub prefs_lookup {
 
     use strict;
     use vars qw($AUTOLOAD $VERSION);
-    $VERSION = sprintf "%.2f", substr(q$Rev: 1379 $,4)/100;
+    $VERSION = sprintf "%.2f", substr(q$Rev: 1399 $,4)/100;
 
     # formerly CPAN::HandleConfig was known as CPAN::Config
     sub AUTOLOAD {
